==> Gambio v4.5.2.2.zip: Vollversion GX v4.5.2.2/Shopsystem/Dateien/GambioAdmin/Modules/ProductDownload/App/ProductDownloadsOptionOperationPermitter.php <==
<?php
/* --------------------------------------------------------------
   ProductDownloadsOptionOperationPermitter.php 2021-09-01
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2021 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ProductDownload\App;

use Gambio\Admin\Modules\Option\Model\Entities\OptionValue;
use Gambio\Admin\Modules\Option\Model\Option;
use Gambio\Admin\Modules\Option\Model\ValueObjects\OptionId;
use Gambio\Admin\Modules\Option\Services\OptionOperationPermitter;
use Gambio\Admin\Modules\ProductDownload\App\Data\ProductDownloadReader;

/**
 * Class ProductDownloadsOptionOperationPermitter
 *
 * @package Gambio\Admin\Modules\ProductDownload\App
 */
class ProductDownloadsOptionOperationPermitter implements OptionOperationPermitter
{
    /**
     * @var ProductDownloadReader
     */
    private $reader;
    
    
    /**
     * ProductOptionsOptionOperationPermitter constructor.
     *
     * @param ProductDownloadReader $reader
     */
    public function __construct(ProductDownloadReader $reader)
    {
        $this->reader = $reader;
    }
    
    
    /**
     * @inheritDoc
     */
    public function permitsCreations(array ...$creationArgs): bool
    {
        return true;
    }
    
    
    /**
     * Checks for each option if other option value IDs are used for product options.
     * If so, some option values have been removed from the option, that can not be deleted.
     *
     * @inheritDoc
     */
    public function permitsStorages(Option ...$options): bool
    {
        foreach ($options as $option) {
            
            $usedValueIds = array_map(static function (OptionValue $optionValue): int {
                return $optionValue->id();
            },
                $option->values()->asArray());
            
            if ($this->reader->areDifferentOptionValuesInUse($option->id(), ...$usedValueIds)) {
                return false;
            }
        }
        
        return true;
    }
    
    
    /**
     * Checks if the given option IDs are used for product options.
     *
     * @inheritDoc
     */
    public function permitsDeletions(OptionId ...$ids): bool
    {
        $idValues = array_map(static function (OptionId $id): int {
            return $id->value();
        },
            $ids);
        
        return $this->reader->isOneOrMoreOptionsInUse(...$idValues) === false;
    }
}

==> Gambio v5.0.2.0.zip: Vollversion GX v5.0.2.0/Shopsystem/Dateien/GambioAdmin/Modules/ProductDownload/App/ProductDownloadsOptionOperationPermitter.php <==
<?php
/* --------------------------------------------------------------
   ProductDownloadsOptionOperationPermitter.php 2023-06-26
   Gambio GmbH
   http://www.gambio.de
   Copyright (c) 2023 Gambio GmbH
   Released under the GNU General Public License (Version 2)
   [http://www.gnu.org/licenses/gpl-2.0.html]
   --------------------------------------------------------------
*/

declare(strict_types=1);

namespace Gambio\Admin\Modules\ProductDownload\App;

use Gambio\Admin\Modules\Option\Model\Option;
use Gambio\Admin\Modules\Option\Model\ValueObjects\OptionId;
use Gambio\Admin\Modules\Option\Services\OptionOperationPermitter;

/**
 * Class ProductDownloadsOptionOperationPermitter
 *
 * @package Gambio\Admin\Modules\ProductDownload\App
 * @deprecated Since 4.7, the gambio shop-system supports submodules. Those product domains were refactored into
 *             submodules too. This class will be deleted with 4.11.
 */
class ProductDownloadsOptionOperationPermitter implements OptionOperationPermitter
{
    public function __construct(
        private \Gambio\Admin\Modules\Product\Submodules\Download\App\ProductDownloadsOptionOperationPermitter $permitter
    ) {
    }
    
    
    /**
     * @inheritDoc
     */
    public function permitsCreations(array ...$creationArgs): bool
    {
        return $this->permitter->permitsCreations(...$creationArgs);
    }
    
    
    /**
     * @inheritDoc
     */
    public function permitsStorages(Option ...$options): bool
    {
        return $this->permitter->permitsStorages(...$options);
    }
    
    
    /**
     * @inheritDoc
     */
    public function permitsDeletions(OptionId ...$ids): bool
    {
        return $this->permitsDeletions(...$ids);
    }
}
